@@ -4,10 +4,6 @@ import (
 	"context"
 	"errors"
 	"fmt"
-
-	"github.com/turbot/steampipe/pkg/dashboard/dashboardserver"
-	"github.com/turbot/steampipe/pkg/statushooks"
-
 	"os"
 	"os/signal"
 	"strings"
@@ -19,8 +15,11 @@ import (
 	"github.com/turbot/go-kit/helpers"
 	"github.com/turbot/steampipe/pkg/cmdconfig"
 	"github.com/turbot/steampipe/pkg/constants"
+	"github.com/turbot/steampipe/pkg/dashboard/dashboardserver"
 	"github.com/turbot/steampipe/pkg/db/db_local"
 	"github.com/turbot/steampipe/pkg/display"
+	"github.com/turbot/steampipe/pkg/error_helpers"
+	"github.com/turbot/steampipe/pkg/statushooks"
 	"github.com/turbot/steampipe/pkg/utils"
 	"github.com/turbot/steampipe/pluginmanager"
 )
@@ -30,7 +29,6 @@ func serviceCmd() *cobra.Command {
 		Use:   "service [command]",
 		Args:  cobra.NoArgs,
 		Short: "Steampipe service management",
-		// TODO(nw) expand long description
 		Long: `Steampipe service management.
 
 Run Steampipe as a local service, exposing it as a database endpoint for
@@ -62,7 +60,7 @@ connection from any Postgres compatible database client.`,
 		OnCmd(cmd).
 		AddBoolFlag(constants.ArgHelp, "h", false, "Help for service start").
 		// for now default port to -1 so we fall back to the default of the deprecated arg
-		AddIntFlag(constants.ArgDatabasePort, "", constants.DatabaseDefaultPort, "Database service port.").
+		AddIntFlag(constants.ArgDatabasePort, "", constants.DatabaseDefaultPort, "Database service port").
 		// for now default listen address to empty so we fall back to the default of the deprecated arg
 		AddStringFlag(constants.ArgListenAddress, "", string(db_local.ListenTypeNetwork), "Accept connections from: local (localhost only) or network (open) (postgres)").
 		AddStringFlag(constants.ArgServicePassword, "", "", "Set the database password for this session").
@@ -71,7 +69,7 @@ connection from any Postgres compatible database client.`,
 		// dashboard server
 		AddBoolFlag(constants.ArgDashboard, "", false, "Run the dashboard webserver with the service").
 		AddStringFlag(constants.ArgDashboardListen, "", string(dashboardserver.ListenTypeNetwork), "Accept connections from: local (localhost only) or network (open) (dashboard)").
-		AddIntFlag(constants.ArgDashboardPort, "", constants.DashboardServerDefaultPort, "Report server port.").
+		AddIntFlag(constants.ArgDashboardPort, "", constants.DashboardServerDefaultPort, "Report server port").
 		// foreground enables the service to run in the foreground - till exit
 		AddBoolFlag(constants.ArgForeground, "", false, "Run the service in the foreground").
 
@@ -151,7 +149,7 @@ func runServiceStartCmd(cmd *cobra.Command, args []string) {
 	defer func() {
 		utils.LogTime("runServiceStartCmd end")
 		if r := recover(); r != nil {
-			utils.ShowError(ctx, helpers.ToError(r))
+			error_helpers.ShowError(ctx, helpers.ToError(r))
 			if exitCode == constants.ExitCodeSuccessful {
 				// there was an error and the exitcode
 				// was not set to a non-zero value.
@@ -170,20 +168,20 @@ func runServiceStartCmd(cmd *cobra.Command, args []string) {
 	}
 
 	serviceListen := db_local.StartListenType(viper.GetString(constants.ArgListenAddress))
-	utils.FailOnError(serviceListen.IsValid())
+	error_helpers.FailOnError(serviceListen.IsValid())
 
 	invoker := constants.Invoker(cmdconfig.Viper().GetString(constants.ArgInvoker))
-	utils.FailOnError(invoker.IsValid())
+	error_helpers.FailOnError(invoker.IsValid())
 
 	err := db_local.EnsureDBInstalled(ctx)
-	utils.FailOnError(err)
+	error_helpers.FailOnError(err)
 
 	// start db, refreshing connections
 	startResult := db_local.StartServices(ctx, port, serviceListen, invoker)
-	utils.FailOnError(startResult.Error)
+	error_helpers.FailOnError(startResult.Error)
 
 	if startResult.Status == db_local.ServiceFailedToStart {
-		utils.ShowError(ctx, fmt.Errorf("steampipe service failed to start"))
+		error_helpers.ShowError(ctx, fmt.Errorf("steampipe service failed to start"))
 		return
 	}
 
@@ -191,17 +189,17 @@ func runServiceStartCmd(cmd *cobra.Command, args []string) {
 
 		// check that we have the same port and listen parameters
 		if port != startResult.DbState.Port {
-			utils.FailOnError(fmt.Errorf("service is already running on port %d - cannot change port while it's running", startResult.DbState.Port))
+			error_helpers.FailOnError(fmt.Errorf("service is already running on port %d - cannot change port while it's running", startResult.DbState.Port))
 		}
 		if serviceListen != startResult.DbState.ListenType {
-			utils.FailOnError(fmt.Errorf("service is already running and listening on %s - cannot change listen type while it's running", startResult.DbState.ListenType))
+			error_helpers.FailOnError(fmt.Errorf("service is already running and listening on %s - cannot change listen type while it's running", startResult.DbState.ListenType))
 		}
 
 		// convert to being invoked by service
 		startResult.DbState.Invoker = constants.InvokerService
 		err = startResult.DbState.Save()
 		if err != nil {
-			utils.FailOnErrorWithMessage(err, "service was already running, but could not make it persistent")
+			error_helpers.FailOnErrorWithMessage(err, "service was already running, but could not make it persistent")
 		}
 	}
 
@@ -212,27 +210,27 @@ func runServiceStartCmd(cmd *cobra.Command, args []string) {
 		if err != nil {
 			_, err1 := db_local.StopServices(ctx, false, constants.InvokerService)
 			if err1 != nil {
-				utils.ShowError(ctx, err1)
+				error_helpers.ShowError(ctx, err1)
 			}
-			utils.FailOnError(err)
+			error_helpers.FailOnError(err)
 		}
 	}
 
-	servicesStarted := (startResult.Status == db_local.ServiceStarted)
+	servicesStarted := startResult.Status == db_local.ServiceStarted
 
 	var dashboardState *dashboardserver.DashboardServiceState
 	if viper.GetBool(constants.ArgDashboard) {
 		dashboardState, err = dashboardserver.GetDashboardServiceState()
 		if err != nil {
 			tryToStopServices(ctx)
-			utils.ShowError(ctx, err)
+			error_helpers.ShowError(ctx, err)
 			return
 		}
 		if dashboardState == nil {
 			dashboardState, err = startDashboardServer(ctx)
 			if err != nil {
+				error_helpers.ShowError(ctx, err)
 				tryToStopServices(ctx)
-				utils.ShowError(ctx, err)
 				return
 			}
 			servicesStarted = true
@@ -247,8 +245,13 @@ func runServiceStartCmd(cmd *cobra.Command, args []string) {
 }
 
 func tryToStopServices(ctx context.Context) {
+	// stop db service
 	if _, err := db_local.StopServices(ctx, false, constants.InvokerService); err != nil {
-		utils.ShowError(ctx, err)
+		error_helpers.ShowError(ctx, err)
+	}
+	// stop the dashboard service
+	if err := dashboardserver.StopDashboardService(ctx); err != nil {
+		error_helpers.ShowError(ctx, err)
 	}
 }
 
@@ -279,7 +282,7 @@ func startDashboardServer(ctx context.Context) (*dashboardserver.DashboardServic
 		// get the updated state
 		dashboardState, err = dashboardserver.GetDashboardServiceState()
 		if err != nil {
-			utils.ShowWarning(fmt.Sprintf("Started Dashboard server, but could not retrieve state: %v", err))
+			error_helpers.ShowWarning(fmt.Sprintf("Started Dashboard server, but could not retrieve state: %v", err))
 		}
 	}
 
@@ -317,7 +320,7 @@ func runServiceInForeground(ctx context.Context, invoker constants.Invoker) {
 			count, err := db_local.GetCountOfThirdPartyClients(context.Background())
 			if err != nil {
 				// report the error in the off chance that there's one
-				utils.ShowError(ctx, err)
+				error_helpers.ShowError(ctx, err)
 				return
 			}
 
@@ -331,7 +334,7 @@ func runServiceInForeground(ctx context.Context, invoker constants.Invoker) {
 			}
 			fmt.Println("Stopping Steampipe service.")
 			if _, err := db_local.StopServices(ctx, false, constants.InvokerService); err != nil {
-				utils.ShowError(ctx, err)
+				error_helpers.ShowError(ctx, err)
 			} else {
 				fmt.Println("Steampipe service stopped.")
 			}
@@ -346,7 +349,7 @@ func runServiceRestartCmd(cmd *cobra.Command, args []string) {
 	defer func() {
 		utils.LogTime("runServiceRestartCmd end")
 		if r := recover(); r != nil {
-			utils.ShowError(ctx, helpers.ToError(r))
+			error_helpers.ShowError(ctx, helpers.ToError(r))
 			if exitCode == constants.ExitCodeSuccessful {
 				// there was an error and the exitcode
 				// was not set to a non-zero value.
@@ -358,7 +361,7 @@ func runServiceRestartCmd(cmd *cobra.Command, args []string) {
 
 	// get current db statue
 	currentDbState, err := db_local.GetState()
-	utils.FailOnError(err)
+	error_helpers.FailOnError(err)
 	if currentDbState == nil {
 		fmt.Println("Steampipe service is not running.")
 		return
@@ -366,11 +369,11 @@ func runServiceRestartCmd(cmd *cobra.Command, args []string) {
 
 	// along with the current dashboard state - maybe nil
 	currentDashboardState, err := dashboardserver.GetDashboardServiceState()
-	utils.FailOnError(err)
+	error_helpers.FailOnError(err)
 
 	// stop db
 	stopStatus, err := db_local.StopServices(ctx, viper.GetBool(constants.ArgForce), constants.InvokerService)
-	utils.FailOnErrorWithMessage(err, "could not stop current instance")
+	error_helpers.FailOnErrorWithMessage(err, "could not stop current instance")
 	if stopStatus != db_local.ServiceStopped {
 		fmt.Println(`
 Service stop failed.
@@ -385,14 +388,14 @@ to force a restart.
 
 	// stop the running dashboard server
 	err = dashboardserver.StopDashboardService(ctx)
-	utils.FailOnErrorWithMessage(err, "could not stop dashboard service")
+	error_helpers.FailOnErrorWithMessage(err, "could not stop dashboard service")
 
 	// set the password in 'viper' so that it can be used by 'service start'
 	viper.Set(constants.ArgServicePassword, currentDbState.Password)
 
 	// start db
 	dbStartResult := db_local.StartServices(cmd.Context(), currentDbState.Port, currentDbState.ListenType, currentDbState.Invoker)
-	utils.FailOnError(dbStartResult.Error)
+	error_helpers.FailOnError(dbStartResult.Error)
 	if dbStartResult.Status == db_local.ServiceFailedToStart {
 		fmt.Println("Steampipe service was stopped, but failed to restart.")
 		return
@@ -400,16 +403,16 @@ to force a restart.
 
 	// refresh connections
 	err = db_local.RefreshConnectionAndSearchPaths(cmd.Context(), constants.InvokerService)
-	utils.FailOnError(err)
+	error_helpers.FailOnError(err)
 
 	// if the dashboard was running, start it
 	if currentDashboardState != nil {
 		err = dashboardserver.RunForService(ctx, dashboardserver.ListenType(currentDashboardState.ListenType), dashboardserver.ListenPort(currentDashboardState.Port))
-		utils.FailOnError(err)
+		error_helpers.FailOnError(err)
 
 		// reload the state
 		currentDashboardState, err = dashboardserver.GetDashboardServiceState()
-		utils.FailOnError(err)
+		error_helpers.FailOnError(err)
 	}
 
 	printStatus(ctx, dbStartResult.DbState, dbStartResult.PluginManagerState, currentDashboardState, false)
@@ -421,7 +424,7 @@ func runServiceStatusCmd(cmd *cobra.Command, args []string) {
 	defer func() {
 		utils.LogTime("runServiceStatusCmd end")
 		if r := recover(); r != nil {
-			utils.ShowError(ctx, helpers.ToError(r))
+			error_helpers.ShowError(ctx, helpers.ToError(r))
 		}
 	}()
 
@@ -437,7 +440,7 @@ func runServiceStatusCmd(cmd *cobra.Command, args []string) {
 		dashboardState, dashboardStateErr := dashboardserver.GetDashboardServiceState()
 
 		if dbStateErr != nil || pmStateErr != nil {
-			utils.ShowError(ctx, composeStateError(dbStateErr, pmStateErr, dashboardStateErr))
+			error_helpers.ShowError(ctx, composeStateError(dbStateErr, pmStateErr, dashboardStateErr))
 			return
 		}
 		printStatus(ctx, dbState, pmState, dashboardState, false)
@@ -470,7 +473,7 @@ func runServiceStopCmd(cmd *cobra.Command, args []string) {
 	defer func() {
 		utils.LogTime("runServiceStopCmd end")
 		if r := recover(); r != nil {
-			utils.ShowError(ctx, helpers.ToError(r))
+			error_helpers.ShowError(ctx, helpers.ToError(r))
 			if exitCode == constants.ExitCodeSuccessful {
 				// there was an error and the exitcode
 				// was not set to a non-zero value.
@@ -484,14 +487,14 @@ func runServiceStopCmd(cmd *cobra.Command, args []string) {
 	if force {
 		dashboardStopError := dashboardserver.StopDashboardService(ctx)
 		status, dbStopError = db_local.StopServices(ctx, force, constants.InvokerService)
-		dbStopError = utils.CombineErrors(dbStopError, dashboardStopError)
-		utils.FailOnError(dbStopError)
+		dbStopError = error_helpers.CombineErrors(dbStopError, dashboardStopError)
+		error_helpers.FailOnError(dbStopError)
 	} else {
 		dbState, dbStopError = db_local.GetState()
-		utils.FailOnErrorWithMessage(dbStopError, "could not stop Steampipe service")
+		error_helpers.FailOnErrorWithMessage(dbStopError, "could not stop Steampipe service")
 
 		dashboardState, err := dashboardserver.GetDashboardServiceState()
-		utils.FailOnErrorWithMessage(err, "could not stop Steampipe service")
+		error_helpers.FailOnErrorWithMessage(err, "could not stop Steampipe service")
 
 		if dbState == nil {
 			fmt.Println("Steampipe service is not running.")
@@ -504,13 +507,13 @@ func runServiceStopCmd(cmd *cobra.Command, args []string) {
 
 		if dashboardState != nil {
 			err = dashboardserver.StopDashboardService(ctx)
-			utils.FailOnErrorWithMessage(err, "could not stop dashboard server")
+			error_helpers.FailOnErrorWithMessage(err, "could not stop dashboard server")
 		}
 
 		var connectedClientCount int
 		// check if there are any connected clients to the service
 		connectedClientCount, err = db_local.GetCountOfThirdPartyClients(cmd.Context())
-		utils.FailOnErrorWithMessage(err, "error during service stop")
+		error_helpers.FailOnErrorWithMessage(err, "service stop failed")
 
 		if connectedClientCount > 0 {
 			printClientsConnected()
@@ -518,7 +521,7 @@ func runServiceStopCmd(cmd *cobra.Command, args []string) {
 		}
 
 		status, err = db_local.StopServices(ctx, false, constants.InvokerService)
-		utils.FailOnErrorWithMessage(err, "error during service stop")
+		error_helpers.FailOnErrorWithMessage(err, "service stop failed")
 	}
 
 	switch status {
@@ -552,7 +555,7 @@ func showAllStatus(ctx context.Context) {
 	processes, err = db_local.FindAllSteampipePostgresInstances(ctx)
 	statushooks.Done(ctx)
 
-	utils.FailOnError(err)
+	error_helpers.FailOnError(err)
 
 	if len(processes) == 0 {
 		fmt.Println("There are no steampipe services running.")
@@ -566,7 +569,7 @@ func showAllStatus(ctx context.Context) {
 		rows = append(rows, []string{pid, installDir, port, string(listen)})
 	}
 
-	display.ShowWrappedTable(headers, rows, false)
+	display.ShowWrappedTable(headers, rows, &display.ShowWrappedTableOptions{AutoMerge: false})
 }
 
 func getServiceProcessDetails(process *psutils.Process) (string, string, string, db_local.StartListenType) {
@@ -623,7 +626,7 @@ Managing the Steampipe service:
 
 	var connectionStr string
 	var password string
-	if viper.IsSet(constants.ArgServiceShowPassword) {
+	if viper.GetBool(constants.ArgServiceShowPassword) {
 		connectionStr = fmt.Sprintf(
 			"postgres://%v:%v@%v:%v/%v",
 			dbState.User,
@@ -706,7 +709,7 @@ To keep the service running after the %s session completes, use %s.
 		// the service is running, but the plugin_manager is not running and there's no state file
 		// meaning that it cannot be restarted by the FDW
 		// it's an ERROR
-		utils.ShowError(ctx, fmt.Errorf(`
+		error_helpers.ShowError(ctx, fmt.Errorf(`
 Service is running, but the Plugin Manager cannot be recovered.
 Please use %s to recover the service
 `,
