@@ -3,8 +3,8 @@ package dashboardexecute
 import (
 	"context"
 	"fmt"
+	"golang.org/x/exp/maps"
 	"log"
-	"strings"
 	"sync"
 	"time"
 
@@ -12,6 +12,7 @@ import (
 	"github.com/turbot/steampipe/pkg/dashboard/dashboardtypes"
 	"github.com/turbot/steampipe/pkg/db/db_common"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
+	"github.com/turbot/steampipe/pkg/utils"
 	"github.com/turbot/steampipe/pkg/workspace"
 )
 
@@ -34,7 +35,6 @@ type DashboardExecutionTree struct {
 	id                     string
 }
 
-// NewDashboardExecutionTree creates a result group from a ModTreeItem
 func NewDashboardExecutionTree(rootName string, sessionId string, client db_common.Client, workspace *workspace.Workspace) (*DashboardExecutionTree, error) {
 	// now populate the DashboardExecutionTree
 	executionTree := &DashboardExecutionTree{
@@ -64,6 +64,14 @@ func (e *DashboardExecutionTree) createRootItem(rootName string) (dashboardtypes
 	if err != nil {
 		return nil, err
 	}
+	if parsedName.ItemType == "" {
+		return nil, fmt.Errorf("root item is not valid named resource")
+	}
+	// if no mod is specified, assume the workspace mod
+	if parsedName.Mod == "" {
+		parsedName.Mod = e.workspace.Mod.ShortName
+		rootName = parsedName.ToFullName()
+	}
 	switch parsedName.ItemType {
 	case modconfig.BlockTypeDashboard:
 		dashboard, ok := e.workspace.GetResourceMaps().Dashboards[rootName]
@@ -77,9 +85,32 @@ func (e *DashboardExecutionTree) createRootItem(rootName string) (dashboardtypes
 			return nil, fmt.Errorf("benchmark '%s' does not exist in workspace", rootName)
 		}
 		return NewCheckRun(benchmark, e, e)
+	case modconfig.BlockTypeQuery:
+		// wrap in a table
+		query, ok := e.workspace.GetResourceMaps().Queries[rootName]
+		if !ok {
+			return nil, fmt.Errorf("query '%s' does not exist in workspace", rootName)
+		}
+		// wrap this in a chart and a dashboard
+		dashboard, err := modconfig.NewQueryDashboard(query)
+		if err != nil {
+			return nil, err
+		}
+		return NewDashboardRun(dashboard, e, e)
+	case modconfig.BlockTypeControl:
+		// wrap in a table
+		control, ok := e.workspace.GetResourceMaps().Controls[rootName]
+		if !ok {
+			return nil, fmt.Errorf("query '%s' does not exist in workspace", rootName)
+		}
+		// wrap this in a chart and a dashboard
+		dashboard, err := modconfig.NewQueryDashboard(control)
+		if err != nil {
+			return nil, err
+		}
+		return NewDashboardRun(dashboard, e, e)
 	default:
-		return nil, fmt.Errorf("reporting type %s cannot be executed directly - only reports may be executed", parsedName.ItemType)
-
+		return nil, fmt.Errorf("reporting type %s cannot be executed as dashboard", parsedName.ItemType)
 	}
 }
 
@@ -98,16 +129,19 @@ func (e *DashboardExecutionTree) Execute(ctx context.Context) {
 		return
 	}
 
-	panels := e.buildSnapshotPanels()
+	panels := e.BuildSnapshotPanels()
+	// build map of those variables referenced by the dashboard run
+	referencedVariables := GetReferencedVariables(e.Root, e.workspace)
+
 	workspace.PublishDashboardEvent(&dashboardevents.ExecutionStarted{
 		Root:        e.Root,
 		Session:     e.sessionId,
 		ExecutionId: e.id,
 		Panels:      panels,
+		Inputs:      e.inputValues,
+		Variables:   referencedVariables,
 	})
 	defer func() {
-		// build map of those variables referenced by the dashboard run
-		referencedVariables := e.getReferencedVariables()
 		e := &dashboardevents.ExecutionComplete{
 			Root:        e.Root,
 			Session:     e.sessionId,
@@ -117,7 +151,7 @@ func (e *DashboardExecutionTree) Execute(ctx context.Context) {
 			Variables:   referencedVariables,
 			// search path elements are quoted (for consumption by postgres)
 			// unquote them
-			SearchPath: unquoteStringArray(e.client.GetRequiredSessionSearchPath()),
+			SearchPath: utils.UnquoteStringArray(e.client.GetRequiredSessionSearchPath()),
 			StartTime:  startTime,
 			EndTime:    time.Now(),
 		}
@@ -143,8 +177,8 @@ func (e *DashboardExecutionTree) GetRunStatus() dashboardtypes.DashboardRunStatu
 }
 
 // SetError sets the error on the Root run
-func (e *DashboardExecutionTree) SetError(err error) {
-	e.Root.SetError(err)
+func (e *DashboardExecutionTree) SetError(ctx context.Context, err error) {
+	e.Root.SetError(ctx, err)
 }
 
 // GetName implements DashboardNodeParent
@@ -166,6 +200,45 @@ func (e *DashboardExecutionTree) ChildCompleteChan() chan dashboardtypes.Dashboa
 	return e.runComplete
 }
 
+func (e *DashboardExecutionTree) Cancel() {
+	// if we have not completed, and already have a cancel function - cancel
+	if e.GetRunStatus() != dashboardtypes.DashboardRunReady || e.cancel == nil {
+		return
+	}
+	e.cancel()
+
+	// if there are any children, wait for the execution to complete
+	if !e.Root.RunComplete() {
+		<-e.runComplete
+	}
+}
+
+func (e *DashboardExecutionTree) GetInputValue(name string) interface{} {
+	return e.inputValues[name]
+}
+
+func (e *DashboardExecutionTree) BuildSnapshotPanels() map[string]dashboardtypes.SnapshotPanel {
+	res := map[string]dashboardtypes.SnapshotPanel{}
+	// if this node is a snapshot node, add to map
+	if snapshotNode, ok := e.Root.(dashboardtypes.SnapshotPanel); ok {
+		res[e.Root.GetName()] = snapshotNode
+	}
+	return e.buildSnapshotPanelsUnder(e.Root, res)
+}
+
+// RuntimeDependencies returns the runtime dependencies for all leaf nodes
+func (e *DashboardExecutionTree) RuntimeDependencies() []string {
+	var deps = map[string]struct{}{}
+	for _, r := range e.runs {
+		if leafRun, ok := r.(*LeafRun); ok {
+			for _, v := range leafRun.runtimeDependencies {
+				deps[v.dependency.SourceResource.GetUnqualifiedName()] = struct{}{}
+			}
+		}
+	}
+	return maps.Keys(deps)
+}
+
 func (e *DashboardExecutionTree) waitForRuntimeDependency(ctx context.Context, dependency *modconfig.RuntimeDependency) error {
 	depChan := make(chan bool, 1)
 
@@ -212,74 +285,9 @@ func (e *DashboardExecutionTree) unsubscribeToInput(inputName string, depChan *c
 	delete(subscribers, depChan)
 }
 
-func (e *DashboardExecutionTree) Cancel() {
-	// if we have not completed, and already have a cancel function - cancel
-	if e.GetRunStatus() != dashboardtypes.DashboardRunReady || e.cancel == nil {
-		return
-	}
-	e.cancel()
-
-	// if there are any children, wait for the execution to complete
-	if !e.Root.RunComplete() {
-		<-e.runComplete
-	}
-}
-
-func (e *DashboardExecutionTree) GetInputValue(name string) interface{} {
-	return e.inputValues[name]
-}
-
-// build map of variables values containing only those mod variables which are referenced
-func (e *DashboardExecutionTree) getReferencedVariables() map[string]string {
-	var referencedVariables = make(map[string]string)
-
-	addReferencedVars := func(refs []*modconfig.ResourceReference) {
-		for _, ref := range refs {
-			parts := strings.Split(ref.To, ".")
-			if len(parts) == 2 && parts[0] == "var" {
-				varName := parts[1]
-				referencedVariables[varName] = e.workspace.VariableValues[varName]
-			}
-		}
-	}
-
-	switch r := e.Root.(type) {
-	case *DashboardRun:
-		r.dashboardNode.WalkResources(
-			func(resource modconfig.HclResource) (bool, error) {
-				addReferencedVars(resource.GetReferences())
-				return true, nil
-			},
-		)
-	case *CheckRun:
-		benchmark, ok := r.DashboardNode.(*modconfig.Benchmark)
-		if !ok {
-			// not expected
-			break
-		}
-		benchmark.WalkResources(
-			func(resource modconfig.ModTreeItem) (bool, error) {
-				addReferencedVars(resource.(modconfig.HclResource).GetReferences())
-				return true, nil
-			},
-		)
-	}
-
-	return referencedVariables
-}
-
-func (e *DashboardExecutionTree) buildSnapshotPanels() map[string]dashboardtypes.SnapshotPanel {
-	res := map[string]dashboardtypes.SnapshotPanel{}
-	// if this node is a snapshot node, add to map
-	if snapshotNode, ok := e.Root.(dashboardtypes.SnapshotPanel); ok {
-		res[e.Root.GetName()] = snapshotNode
-	}
-	return e.buildSnapshotPanelsUnder(e.Root, res)
-}
-
 func (e *DashboardExecutionTree) buildSnapshotPanelsUnder(parent dashboardtypes.DashboardNodeRun, res map[string]dashboardtypes.SnapshotPanel) map[string]dashboardtypes.SnapshotPanel {
 	if checkRun, ok := parent.(*CheckRun); ok {
-		return checkRun.buildSnapshotPanels(res)
+		return checkRun.BuildSnapshotPanels(res)
 	}
 	for _, c := range parent.GetChildren() {
 		// if this node is a snapshot node, add to map
@@ -291,12 +299,3 @@ func (e *DashboardExecutionTree) buildSnapshotPanelsUnder(parent dashboardtypes.
 
 	return res
 }
-
-// remove quote marks from elements of string array
-func unquoteStringArray(stringArray []string) []string {
-	res := make([]string, len(stringArray))
-	for i, s := range stringArray {
-		res[i] = strings.Replace(s, `"`, ``, -1)
-	}
-	return res
-}
