@@ -4,7 +4,6 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
-	"github.com/turbot/steampipe/pkg/utils"
 	"log"
 	"os"
 	"reflect"
@@ -16,6 +15,7 @@ import (
 	"github.com/turbot/steampipe/pkg/dashboard/dashboardevents"
 	"github.com/turbot/steampipe/pkg/dashboard/dashboardexecute"
 	"github.com/turbot/steampipe/pkg/db/db_common"
+	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/workspace"
 	"gopkg.in/olahol/melody.v1"
@@ -50,7 +50,7 @@ func NewServer(ctx context.Context, dbClient db_common.Client, w *workspace.Work
 		workspace:        w,
 	}
 
-	w.RegisterDashboardEventHandler(server.HandleWorkspaceUpdate)
+	w.RegisterDashboardEventHandler(server.HandleDashboardEvent)
 	err := w.SetupWatcher(ctx, dbClient, func(c context.Context, e error) {})
 	OutputMessage(ctx, "Workspace loaded")
 
@@ -66,27 +66,21 @@ func (s *Server) Start() chan struct{} {
 
 // Shutdown stops the API server
 func (s *Server) Shutdown() {
-	log.Println("[TRACE] server shutdown")
+	log.Println("[TRACE] Server shutdown")
 
 	if s.webSocket != nil {
 		log.Println("[TRACE] closing websocket")
 		if err := s.webSocket.Close(); err != nil {
-			utils.ShowErrorWithMessage(s.context, err, "Websocket shutdown failed")
+			error_helpers.ShowErrorWithMessage(s.context, err, "Websocket shutdown failed")
 		}
 		log.Println("[TRACE] closed websocket")
 	}
 
-	// Close the workspace
-	if s.workspace != nil {
-		log.Println("[TRACE] closing workspace")
-		s.workspace.Close()
-		log.Println("[TRACE] closed workspace")
-	}
+	log.Println("[TRACE] Server shutdown complete")
 
-	log.Println("[TRACE] server shutdown complete")
 }
 
-func (s *Server) HandleWorkspaceUpdate(event dashboardevents.DashboardEvent) {
+func (s *Server) HandleDashboardEvent(event dashboardevents.DashboardEvent) {
 	var payloadError error
 	var payload []byte
 	defer func() {
@@ -107,7 +101,7 @@ func (s *Server) HandleWorkspaceUpdate(event dashboardevents.DashboardEvent) {
 			return
 		}
 		_ = s.webSocket.Broadcast(payload)
-		outputError(s.context, e.Error)
+		OutputError(s.context, e.Error)
 
 	case *dashboardevents.ExecutionStarted:
 		log.Printf("[TRACE] ExecutionStarted event session %s, dashboard %s", e.Session, e.Root.GetName())
@@ -126,7 +120,7 @@ func (s *Server) HandleWorkspaceUpdate(event dashboardevents.DashboardEvent) {
 		}
 
 		s.writePayloadToSession(e.Session, payload)
-		outputError(s.context, e.Error)
+		OutputError(s.context, e.Error)
 
 	case *dashboardevents.ExecutionComplete:
 		log.Println("[TRACE] execution complete event", *e)
@@ -176,6 +170,7 @@ func (s *Server) HandleWorkspaceUpdate(event dashboardevents.DashboardEvent) {
 		changedCards := e.ChangedCards
 		changedCharts := e.ChangedCharts
 		changedFlows := e.ChangedFlows
+		changedGraphs := e.ChangedGraphs
 		changedHierarchies := e.ChangedHierarchies
 		changedImages := e.ChangedImages
 		changedInputs := e.ChangedInputs
@@ -192,6 +187,7 @@ func (s *Server) HandleWorkspaceUpdate(event dashboardevents.DashboardEvent) {
 			len(changedCards) == 0 &&
 			len(changedCharts) == 0 &&
 			len(changedFlows) == 0 &&
+			len(changedGraphs) == 0 &&
 			len(changedHierarchies) == 0 &&
 			len(changedImages) == 0 &&
 			len(changedInputs) == 0 &&
@@ -238,6 +234,7 @@ func (s *Server) HandleWorkspaceUpdate(event dashboardevents.DashboardEvent) {
 		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedCards)...)
 		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedCharts)...)
 		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedFlows)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedGraphs)...)
 		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedHierarchies)...)
 		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedImages)...)
 		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedInputs)...)
@@ -303,7 +300,6 @@ func (s *Server) HandleWorkspaceUpdate(event dashboardevents.DashboardEvent) {
 			// 			outputMessage(s.context, fmt.Sprintf("Input Values Cleared - dashboard inputs updated: %v", sessionInfo.DashboardInputs))
 		}
 		s.writePayloadToSession(e.Session, payload)
-
 	}
 }
 
@@ -358,6 +354,19 @@ func (s *Server) handleMessageFunc(ctx context.Context) func(session *melody.Ses
 		case "select_dashboard":
 			s.setDashboardForSession(sessionId, request.Payload.Dashboard.FullName, request.Payload.InputValues)
 			_ = dashboardexecute.Executor.ExecuteDashboard(ctx, sessionId, request.Payload.Dashboard.FullName, request.Payload.InputValues, s.workspace, s.dbClient)
+		case "select_snapshot":
+			snapshotName := request.Payload.Dashboard.FullName
+			s.setDashboardForSession(sessionId, snapshotName, request.Payload.InputValues)
+			snap, err := dashboardexecute.Executor.LoadSnapshot(ctx, sessionId, snapshotName, s.workspace)
+			// TACTICAL- handle with error message
+			error_helpers.FailOnError(err)
+			// error handling???
+			payload, err := buildDisplaySnapshotPayload(snap)
+			// TACTICAL- handle with error message
+			error_helpers.FailOnError(err)
+
+			s.writePayloadToSession(sessionId, payload)
+			outputReady(s.context, fmt.Sprintf("Show snapshot complete: %s", snapshotName))
 		case "input_changed":
 			s.setDashboardInputsForSession(sessionId, request.Payload.InputValues)
 			_ = dashboardexecute.Executor.OnInputChanged(ctx, sessionId, request.Payload.InputValues, request.Payload.ChangedInput)
@@ -365,7 +374,6 @@ func (s *Server) handleMessageFunc(ctx context.Context) func(session *melody.Ses
 			s.setDashboardInputsForSession(sessionId, nil)
 			dashboardexecute.Executor.CancelExecutionForSession(ctx, sessionId)
 		}
-
 	}
 }
 
