@@ -2,7 +2,6 @@ package db_local
 
 import (
 	"context"
-	"database/sql"
 	"errors"
 	"fmt"
 	"log"
@@ -10,9 +9,13 @@ import (
 	"os"
 	"os/exec"
 	"sync"
+	"time"
 
 	"github.com/fatih/color"
+	"github.com/jackc/pgx/v4"
+	"github.com/sethvargo/go-retry"
 	psutils "github.com/shirou/gopsutil/process"
+	filehelpers "github.com/turbot/go-kit/files"
 	"github.com/turbot/go-kit/helpers"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_common"
@@ -216,7 +219,7 @@ func prepareDb(ctx context.Context) error {
 		// get the message renderer from the context
 		// this allows the interactive client init to inject a custom renderer
 		messageRenderer := statushooks.MessageRendererFromContext(ctx)
-		messageRenderer("%s was updated to %s.\n", constants.Bold("steampipe-postgres-fdw"), constants.Bold(constants.FdwVersion))
+		messageRenderer("%s was updated to %s.", constants.Bold("steampipe-postgres-fdw"), constants.Bold(constants.FdwVersion))
 	}
 
 	if needsInit() {
@@ -263,7 +266,7 @@ func needsInit() bool {
 	defer utils.LogTime("db_local.needsInit end")
 
 	// test whether pg_hba.conf exists in our target directory
-	return !helpers.FileExists(getPgHbaConfLocation())
+	return !filehelpers.FileExists(getPgHbaConfLocation())
 }
 
 func runInstall(ctx context.Context, oldDbName *string) error {
@@ -306,7 +309,7 @@ func runInstall(ctx context.Context, oldDbName *string) error {
 	}
 	defer func() {
 		statushooks.SetStatus(ctx, "Completing configuration")
-		client.Close()
+		client.Close(ctx)
 		doThreeStepPostgresExit(ctx, process)
 	}()
 
@@ -366,25 +369,32 @@ func resolveDatabaseName(oldDbName *string) string {
 
 // createMaintenanceClient connects to the postgres server using the
 // maintenance database and superuser
-func createMaintenanceClient(ctx context.Context, port int) (*sql.DB, error) {
-	psqlInfo := fmt.Sprintf("host=localhost port=%d user=%s dbname=postgres sslmode=disable", port, constants.DatabaseSuperUser)
-
-	log.Println("[TRACE] Connection string: ", psqlInfo)
-
-	// connect to the database using the postgres driver
-	utils.LogTime("db_local.createClient connection open start")
-	db, err := sql.Open("pgx", psqlInfo)
-	db.SetMaxOpenConns(1)
-	utils.LogTime("db_local.createClient connection open end")
-
+func createMaintenanceClient(ctx context.Context, port int) (*pgx.Conn, error) {
+	backoff, err := retry.NewConstant(200 * time.Millisecond)
 	if err != nil {
 		return nil, err
 	}
+	var conn *pgx.Conn
 
-	if err := db_common.WaitForConnection(ctx, db); err != nil {
+	err = retry.Do(ctx, retry.WithMaxRetries(5, backoff), func(ctx context.Context) error {
+		connStr := fmt.Sprintf("host=localhost port=%d user=%s dbname=postgres sslmode=disable", port, constants.DatabaseSuperUser)
+		log.Println("[TRACE] Connection string: ", connStr)
+		utils.LogTime("db_local.createClient connection open start")
+		conn, err = pgx.Connect(context.Background(), connStr)
+		utils.LogTime("db_local.createClient connection open end")
+		if err != nil {
+			return retry.RetryableError(err)
+		}
+		if err := db_common.WaitForConnection(ctx, conn); err != nil {
+			return retry.RetryableError(err)
+		}
+		return nil
+	})
+	if err != nil {
 		return nil, err
 	}
-	return db, nil
+	return conn, nil
+
 }
 
 func startServiceForInstall(port int) (*psutils.Process, error) {
@@ -418,7 +428,7 @@ func startServiceForInstall(port int) (*psutils.Process, error) {
 func getNextFreePort() (int, error) {
 	utils.LogTime("db_local.install.getNextFreePort start")
 	defer utils.LogTime("db_local.install.getNextFreePort end")
-	listener, err := net.Listen("tcp", ":0")
+	listener, err := net.Listen("tcp", "127.0.0.1:0")
 	if err != nil {
 		return -1, err
 	}
@@ -436,7 +446,7 @@ func initDatabase() error {
 
 	// initdb sometimes fail due to invalid locale settings, to avoid this we update
 	// the locale settings to use 'C' only for the initdb process to complete, and
-	// then return back to the existing locale settings of the user.
+	// then return to the existing locale settings of the user.
 	// set LC_ALL env variable to override current locale settings
 	err := os.Setenv("LC_ALL", "C")
 	if err != nil {
@@ -447,12 +457,18 @@ func initDatabase() error {
 	initDBExecutable := getInitDbBinaryExecutablePath()
 	initDbProcess := exec.Command(
 		initDBExecutable,
+		// Steampipe runs Postgres as a local, embedded database so trust local
+		// users to login without a password.
 		fmt.Sprintf("--auth=%s", "trust"),
+		// Ensure the name of the database superuser is consistent across installs.
+		// By default it would be based on the user running the install of this
+		// embedded database.
 		fmt.Sprintf("--username=%s", constants.DatabaseSuperUser),
+		// Postgres data should placed under the Steampipe install directory.
 		fmt.Sprintf("--pgdata=%s", getDataLocation()),
+		// Ensure the encoding is consistent across installs. By default it would
+		// be based on the system locale.
 		fmt.Sprintf("--encoding=%s", "UTF-8"),
-		fmt.Sprintf("--wal-segsize=%d", 1),
-		"--debug",
 	)
 
 	log.Printf("[TRACE] initdb start: %s", initDbProcess.String())
@@ -463,7 +479,7 @@ func initDatabase() error {
 		return runError
 	}
 
-	// unset LC_ALL to return back to original locale settings
+	// unset LC_ALL to return to original locale settings
 	err = os.Unsetenv("LC_ALL")
 	if err != nil {
 		log.Printf("[TRACE] failed to return back to original locale settings:\n %s", err.Error())
@@ -475,7 +491,7 @@ func initDatabase() error {
 	return os.WriteFile(getPgHbaConfLocation(), []byte(constants.MinimalPgHbaContent), 0600)
 }
 
-func installDatabaseWithPermissions(ctx context.Context, databaseName string, rawClient *sql.DB) error {
+func installDatabaseWithPermissions(ctx context.Context, databaseName string, rawClient *pgx.Conn) error {
 	utils.LogTime("db_local.install.installDatabaseWithPermissions start")
 	defer utils.LogTime("db_local.install.installDatabaseWithPermissions end")
 
@@ -536,7 +552,7 @@ func installDatabaseWithPermissions(ctx context.Context, databaseName string, ra
 	for _, statement := range statements {
 		// not logging here, since the password may get logged
 		// we don't want that
-		if _, err := rawClient.ExecContext(ctx, statement); err != nil {
+		if _, err := rawClient.Exec(ctx, statement); err != nil {
 			return err
 		}
 	}
@@ -548,7 +564,7 @@ func writePgHbaContent(databaseName string, username string) error {
 	return os.WriteFile(getPgHbaConfLocation(), []byte(content), 0600)
 }
 
-func installForeignServer(ctx context.Context, rawClient *sql.DB) error {
+func installForeignServer(ctx context.Context, rawClient *pgx.Conn) error {
 	utils.LogTime("db_local.installForeignServer start")
 	defer utils.LogTime("db_local.installForeignServer end")
 
@@ -564,7 +580,7 @@ func installForeignServer(ctx context.Context, rawClient *sql.DB) error {
 		// NOTE: This may print a password to the log file, but it doesn't matter
 		// since the password is stored in a config file anyway.
 		log.Println("[TRACE] Install Foreign Server: ", statement)
-		if _, err := rawClient.ExecContext(ctx, statement); err != nil {
+		if _, err := rawClient.Exec(ctx, statement); err != nil {
 			return err
 		}
 	}
