@@ -1,6 +1,7 @@
 package interactive
 
 import (
+	"bytes"
 	"context"
 	"fmt"
 	"log"
@@ -21,6 +22,7 @@ import (
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_common"
 	"github.com/turbot/steampipe/pkg/display"
+	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/query"
 	"github.com/turbot/steampipe/pkg/query/metaquery"
 	"github.com/turbot/steampipe/pkg/query/queryhistory"
@@ -62,6 +64,7 @@ type InteractiveClient struct {
 	schemaMetadata *schema.Metadata
 	highlighter    *Highlighter
 	hidePrompt     bool
+	suggestions    []prompt.Suggest
 }
 
 func getHighlighter(theme string) *Highlighter {
@@ -104,7 +107,7 @@ func (c *InteractiveClient) InteractivePrompt(parentContext context.Context) {
 
 	defer func() {
 		if r := recover(); r != nil {
-			utils.ShowError(ctx, helpers.ToError(r))
+			error_helpers.ShowError(ctx, helpers.ToError(r))
 		}
 		// close up the SIGINT channel so that the receiver goroutine can quit
 		quitChannel <- true
@@ -150,6 +153,54 @@ func (c *InteractiveClient) InteractivePrompt(parentContext context.Context) {
 	}
 }
 
+func (c *InteractiveClient) initialiseSuggestions() {
+	var res []prompt.Suggest
+
+	workspaceModName := c.initData.Workspace.Mod.Name()
+	resourceFunc := func(item modconfig.HclResource) (continueWalking bool, err error) {
+		continueWalking = true
+
+		qp, ok := item.(modconfig.QueryProvider)
+		if !ok {
+			return
+		}
+		if qp.GetQuery() == nil && qp.GetSQL() == nil {
+			return
+		}
+		rm := item.(modconfig.ResourceWithMetadata)
+		if rm.IsAnonymous() {
+			return
+		}
+		isLocal := qp.GetMod().Name() == workspaceModName
+		itemType := item.BlockType()
+		// only include global inputs
+		if itemType == modconfig.BlockTypeInput {
+			if _, ok := c.initData.Workspace.Mod.ResourceMaps.GlobalDashboardInputs[item.Name()]; !ok {
+				return
+			}
+		}
+		// special case for query
+		if itemType == modconfig.BlockTypeQuery {
+			itemType = "named query"
+		}
+		name := qp.Name()
+		if isLocal {
+			name = qp.GetUnqualifiedName()
+		}
+
+		res = append(res, c.addSuggestion(itemType, qp.GetDescription(), name))
+		return
+	}
+
+	c.workspace().GetResourceMaps().WalkResources(resourceFunc)
+
+	// sort the suggestions
+	sort.Slice(res, func(i, j int) bool {
+		return res[i].Text < res[j].Text
+	})
+	c.suggestions = res
+}
+
 // ClosePrompt cancels the running prompt, setting the action to take after close
 func (c *InteractiveClient) ClosePrompt(afterClose AfterPromptCloseAction) {
 	c.afterClose = afterClose
@@ -295,6 +346,13 @@ func (c *InteractiveClient) runInteractivePrompt(ctx context.Context) (ret utils
 			ASCIICode: constants.AltRightArrowASCIICode,
 			Fn:        prompt.GoRightWord,
 		}),
+		prompt.OptionBufferPreHook(func(input string) (modifiedInput string, ignore bool) {
+			// if this is not WSL, return as-is
+			if !utils.IsWSL() {
+				return input, false
+			}
+			return cleanBufferForWSL(input)
+		}),
 	)
 	// set this to a default
 	c.autocompleteOnEmpty = false
@@ -303,6 +361,18 @@ func (c *InteractiveClient) runInteractivePrompt(ctx context.Context) (ret utils
 	return
 }
 
+func cleanBufferForWSL(s string) (string, bool) {
+	b := []byte(s)
+	// in WSL, 'Alt' combo-characters are denoted by [27, ASCII of character]
+	// if we get a combination which has 27 as prefix - we should ignore it
+	// this is inline with other interactive clients like pgcli
+	if len(b) > 1 && bytes.HasPrefix(b, []byte{byte(27)}) {
+		// ignore it
+		return "", true
+	}
+	return string(b), false
+}
+
 func (c *InteractiveClient) breakMultilinePrompt(buffer *prompt.Buffer) {
 	c.interactiveBuffer = []string{}
 }
@@ -329,11 +399,11 @@ func (c *InteractiveClient) executor(ctx context.Context, line string) {
 	// we successfully retrieved a query
 
 	// create a  context for the execution of the query
-	queryContext := c.createQueryContext(ctx)
+	queryCtx := c.createQueryContext(ctx)
 
 	if metaquery.IsMetaQuery(query) {
-		if err := c.executeMetaquery(queryContext, query); err != nil {
-			utils.ShowError(ctx, err)
+		if err := c.executeMetaquery(queryCtx, query); err != nil {
+			error_helpers.ShowError(ctx, err)
 		}
 		// cancel the context
 		c.cancelActiveQueryIfAny()
@@ -341,9 +411,9 @@ func (c *InteractiveClient) executor(ctx context.Context, line string) {
 	} else {
 		// otherwise execute query
 		t := time.Now()
-		result, err := c.client().Execute(queryContext, query)
+		result, err := c.client().Execute(queryCtx, query)
 		if err != nil {
-			utils.ShowError(ctx, utils.HandleCancelError(err))
+			error_helpers.ShowError(ctx, error_helpers.HandleCancelError(err))
 			// if timing flag is enabled, show the time taken for the query to fail
 			if cmdconfig.Viper().GetBool(constants.ArgTiming) {
 				display.DisplayErrorTiming(t)
@@ -377,7 +447,7 @@ func (c *InteractiveClient) getQuery(ctx context.Context, line string) string {
 	if !c.isInitialised() {
 		// create a context used purely to detect cancellation during initialisation
 		// this will also set c.cancelActiveQuery
-		queryContext := c.createQueryContext(ctx)
+		queryCtx := c.createQueryContext(ctx)
 		defer func() {
 			// cancel this context
 			c.cancelActiveQueryIfAny()
@@ -385,7 +455,7 @@ func (c *InteractiveClient) getQuery(ctx context.Context, line string) string {
 
 		statushooks.SetStatus(ctx, "Initializing...")
 		// wait for client initialisation to complete
-		err := c.waitForInitData(queryContext)
+		err := c.waitForInitData(queryCtx)
 		statushooks.Done(ctx)
 		if err != nil {
 			// clear history entry
@@ -411,7 +481,7 @@ func (c *InteractiveClient) getQuery(ctx context.Context, line string) string {
 		// - do not clear history item - we want to store bad entry in history
 		// - clear interactive buffer
 		c.interactiveBuffer = nil
-		utils.ShowError(ctx, err)
+		error_helpers.ShowError(ctx, err)
 		return ""
 	}
 	isNamedQuery := queryProvider != nil
@@ -502,6 +572,9 @@ func (c *InteractiveClient) shouldExecute(line string, namedQuery bool) bool {
 }
 
 func (c *InteractiveClient) queryCompleter(d prompt.Document) []prompt.Suggest {
+	if !cmdconfig.Viper().GetBool(constants.ArgAutoComplete) {
+		return nil
+	}
 	if !c.isInitialised() {
 		return nil
 	}
@@ -524,7 +597,7 @@ func (c *InteractiveClient) queryCompleter(d prompt.Document) []prompt.Suggest {
 		// add all we know that can be the first words
 
 		// named queries
-		s = append(s, c.namedQuerySuggestions()...)
+		s = append(s, c.suggestions...)
 		// "select"
 		s = append(s, prompt.Suggest{Text: "select", Output: "select"}, prompt.Suggest{Text: "with", Output: "with"})
 
@@ -556,52 +629,15 @@ func (c *InteractiveClient) queryCompleter(d prompt.Document) []prompt.Suggest {
 		// }
 
 	}
+
 	return prompt.FilterHasPrefix(s, d.GetWordBeforeCursor(), true)
 }
 
-func (c *InteractiveClient) namedQuerySuggestions() []prompt.Suggest {
-	var res []prompt.Suggest
-	// only add named query suggestions if the client is initialised
-	if !c.isInitialised() {
-		return nil
+func (c *InteractiveClient) addSuggestion(itemType string, description string, name string) prompt.Suggest {
+	if description != "" {
+		itemType += fmt.Sprintf(": %s", description)
 	}
-	resourceMaps := c.workspace().GetResourceMaps()
-	// add all the queries in the workspace
-	for queryName, q := range resourceMaps.LocalQueries {
-		res = append(res, c.addQuerySuggestion(q, queryName))
-	}
-	for queryName, q := range resourceMaps.Queries {
-		res = append(res, c.addQuerySuggestion(q, queryName))
-	}
-
-	// add all the controls in the workspace
-	for controlName, control := range resourceMaps.LocalControls {
-		res = append(res, c.addControlSuggestion(control, controlName))
-	}
-	for controlName, control := range resourceMaps.Controls {
-		res = append(res, c.addControlSuggestion(control, controlName))
-	}
-
-	sort.Slice(res, func(i, j int) bool {
-		return res[i].Text < res[j].Text
-	})
-	return res
-}
-
-func (c *InteractiveClient) addQuerySuggestion(query *modconfig.Query, queryName string) prompt.Suggest {
-	description := "named query"
-	if query.Description != nil {
-		description += fmt.Sprintf(": %s", *query.Description)
-	}
-	return prompt.Suggest{Text: queryName, Output: queryName, Description: description}
-}
-
-func (c *InteractiveClient) addControlSuggestion(control *modconfig.Control, controlName string) prompt.Suggest {
-	description := "control"
-	if control.Description != nil {
-		description += fmt.Sprintf(": %s", *control.Description)
-	}
-	return prompt.Suggest{Text: controlName, Output: controlName, Description: description}
+	return prompt.Suggest{Text: name, Output: name, Description: itemType}
 }
 
 func (c *InteractiveClient) startCancelHandler() chan bool {
