@@ -11,6 +11,7 @@ import (
 	"github.com/turbot/steampipe/pkg/contexthelpers"
 	"github.com/turbot/steampipe/pkg/db/db_common"
 	"github.com/turbot/steampipe/pkg/display"
+	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/interactive"
 	"github.com/turbot/steampipe/pkg/query"
 	"github.com/turbot/steampipe/pkg/utils"
@@ -22,7 +23,7 @@ func RunInteractiveSession(ctx context.Context, initData *query.InitData) {
 
 	// the db executor sends result data over resultsStreamer
 	resultsStreamer, err := interactive.RunInteractivePrompt(ctx, initData)
-	utils.FailOnError(err)
+	error_helpers.FailOnError(err)
 
 	// print the data as it comes
 	for r := range resultsStreamer.Results {
@@ -33,9 +34,6 @@ func RunInteractiveSession(ctx context.Context, initData *query.InitData) {
 }
 
 func RunBatchSession(ctx context.Context, initData *query.InitData) int {
-	// ensure we close client
-	defer initData.Cleanup(ctx)
-
 	// start cancel handler to intercept interrupts and cancel the context
 	// NOTE: use the initData Cancel function to ensure any initialisation is cancelled if needed
 	contexthelpers.StartCancelHandler(initData.Cancel)
@@ -43,7 +41,7 @@ func RunBatchSession(ctx context.Context, initData *query.InitData) int {
 	// wait for init
 	<-initData.Loaded
 	if err := initData.Result.Error; err != nil {
-		utils.FailOnError(err)
+		error_helpers.FailOnError(err)
 	}
 
 	// display any initialisation messages/warnings
@@ -52,23 +50,28 @@ func RunBatchSession(ctx context.Context, initData *query.InitData) int {
 	failures := 0
 	if len(initData.Queries) > 0 {
 		// if we have resolved any queries, run them
-		failures = executeQueries(ctx, initData.Queries, initData.Client)
+		failures = executeQueries(ctx, initData)
 	}
 	// set global exit code
 	return failures
 }
 
-func executeQueries(ctx context.Context, queries []string, client db_common.Client) int {
+func executeQueries(ctx context.Context, initData *query.InitData) int {
 	utils.LogTime("queryexecute.executeQueries start")
 	defer utils.LogTime("queryexecute.executeQueries end")
 
 	// run all queries
 	failures := 0
 	t := time.Now()
-	for i, q := range queries {
-		if err := executeQuery(ctx, q, client); err != nil {
+	// build ordered list of queries
+	// (ordered for testing repeatability)
+	var queryNames []string = utils.SortedMapKeys(initData.Queries)
+
+	for i, name := range queryNames {
+		q := initData.Queries[name]
+		if err := executeQuery(ctx, q, initData.Client); err != nil {
 			failures++
-			utils.ShowWarning(fmt.Sprintf("executeQueries: query %d of %d failed: %v", i+1, len(queries), err))
+			error_helpers.ShowWarning(fmt.Sprintf("executeQueries: query %d of %d failed: %v", i+1, len(queryNames), error_helpers.DecodePgError(err)))
 			// if timing flag is enabled, show the time taken for the query to fail
 			if cmdconfig.Viper().GetBool(constants.ArgTiming) {
 				display.DisplayErrorTiming(t)
@@ -76,7 +79,7 @@ func executeQueries(ctx context.Context, queries []string, client db_common.Clie
 		}
 		// TODO move into display layer
 		// Only show the blank line between queries, not after the last one
-		if (i < len(queries)-1) && showBlankLineBetweenResults() {
+		if (i < len(queryNames)-1) && showBlankLineBetweenResults() {
 			fmt.Println()
 		}
 	}
