@@ -74,7 +74,7 @@ func (i *DashboardInput) Clone() *DashboardInput {
 	}
 }
 
-func NewDashboardInput(block *hcl.Block, mod *Mod, shortName string) *DashboardInput {
+func NewDashboardInput(block *hcl.Block, mod *Mod, shortName string) HclResource {
 	// input cannot be anonymous
 	i := &DashboardInput{
 		ShortName:       shortName,
@@ -106,22 +106,22 @@ func (i *DashboardInput) Name() string {
 }
 
 // OnDecoded implements HclResource
-func (i *DashboardInput) OnDecoded(block *hcl.Block, resourceMapProvider ModResourcesProvider) hcl.Diagnostics {
+func (i *DashboardInput) OnDecoded(block *hcl.Block, resourceMapProvider ResourceMapsProvider) hcl.Diagnostics {
 	i.setBaseProperties(resourceMapProvider)
 	return nil
 }
 
-// AddReference implements HclResource
+// AddReference implements ResourceWithMetadata
 func (i *DashboardInput) AddReference(ref *ResourceReference) {
 	i.References = append(i.References, ref)
 }
 
-// GetReferences implements HclResource
+// GetReferences implements ResourceWithMetadata
 func (i *DashboardInput) GetReferences() []*ResourceReference {
 	return i.References
 }
 
-// GetMod implements HclResource
+// GetMod implements ModTreeItem
 func (i *DashboardInput) GetMod() *Mod {
 	return i.Mod
 }
@@ -131,6 +131,11 @@ func (i *DashboardInput) GetDeclRange() *hcl.Range {
 	return &i.DeclRange
 }
 
+// BlockType implements HclResource
+func (*DashboardInput) BlockType() string {
+	return BlockTypeInput
+}
+
 // AddParent implements ModTreeItem
 func (i *DashboardInput) AddParent(parent ModTreeItem) error {
 	i.parents = append(i.parents, parent)
@@ -147,7 +152,7 @@ func (i *DashboardInput) GetChildren() []ModTreeItem {
 	return nil
 }
 
-// GetTitle implements ModTreeItem
+// GetTitle implements HclResource
 func (i *DashboardInput) GetTitle() string {
 	return typehelpers.SafeString(i.Title)
 }
@@ -157,9 +162,9 @@ func (i *DashboardInput) GetDescription() string {
 	return ""
 }
 
-// GetTags implements ModTreeItem
+// GetTags implements HclResource
 func (i *DashboardInput) GetTags() map[string]string {
-	return nil
+	return map[string]string{}
 }
 
 // GetPaths implements ModTreeItem
@@ -229,7 +234,7 @@ func (i *DashboardInput) GetDisplay() string {
 	return typehelpers.SafeString(i.Display)
 }
 
-// GetDocumentation implements DashboardLeafNode
+// GetDocumentation implements DashboardLeafNode, ModTreeItem
 func (*DashboardInput) GetDocumentation() string {
 	return ""
 }
@@ -311,7 +316,7 @@ func (i *DashboardInput) DependsOnInput(changedInputName string) bool {
 	return false
 }
 
-func (i *DashboardInput) setBaseProperties(resourceMapProvider ModResourcesProvider) {
+func (i *DashboardInput) setBaseProperties(resourceMapProvider ResourceMapsProvider) {
 	// not all base properties are stored in the evalContext
 	// (e.g. resource metadata and runtime dependencies are not stores)
 	//  so resolve base from the resource map provider (which is the RunContext)
