@@ -2,7 +2,6 @@ package modconfig
 
 import (
 	"fmt"
-
 	"github.com/turbot/steampipe/pkg/constants"
 
 	"github.com/turbot/steampipe/pkg/utils"
@@ -47,7 +46,7 @@ type DashboardTable struct {
 	parents []ModTreeItem
 }
 
-func NewDashboardTable(block *hcl.Block, mod *Mod, shortName string) *DashboardTable {
+func NewDashboardTable(block *hcl.Block, mod *Mod, shortName string) HclResource {
 	t := &DashboardTable{
 		ShortName:       shortName,
 		FullName:        fmt.Sprintf("%s.%s.%s", mod.ShortName, block.Type, shortName),
@@ -59,6 +58,35 @@ func NewDashboardTable(block *hcl.Block, mod *Mod, shortName string) *DashboardT
 	return t
 }
 
+// NewQueryDashboardTable creates a Table to wrap a query.
+// This is used in order to execute queries as dashboards
+func NewQueryDashboardTable(q ModTreeItem) (*DashboardTable, error) {
+	parsedName, err := ParseResourceName(q.Name())
+	if err != nil {
+		return nil, err
+	}
+
+	queryProvider, ok := q.(QueryProvider)
+	if !ok {
+		return nil, fmt.Errorf("rersource passed to NewQueryDashboardTable must implement QueryProvider")
+	}
+
+	tableName := BuildFullResourceName(q.GetMod().ShortName, BlockTypeTable, parsedName.Name)
+	c := &DashboardTable{
+		ResourceWithMetadataBase: ResourceWithMetadataBase{
+			metadata: &ResourceMetadata{},
+		},
+		ShortName:       parsedName.Name,
+		FullName:        tableName,
+		UnqualifiedName: fmt.Sprintf("%s.%s", BlockTypeTable, parsedName),
+		Title:           utils.ToStringPointer(q.GetTitle()),
+		Mod:             q.GetMod(),
+		Query:           queryProvider.GetQuery(),
+		SQL:             queryProvider.GetSQL(),
+	}
+	return c, nil
+}
+
 func (t *DashboardTable) Equals(other *DashboardTable) bool {
 	diff := t.Diff(other)
 	return !diff.HasChanges()
@@ -76,7 +104,7 @@ func (t *DashboardTable) Name() string {
 }
 
 // OnDecoded implements HclResource
-func (t *DashboardTable) OnDecoded(_ *hcl.Block, resourceMapProvider ModResourcesProvider) hcl.Diagnostics {
+func (t *DashboardTable) OnDecoded(_ *hcl.Block, resourceMapProvider ResourceMapsProvider) hcl.Diagnostics {
 	t.setBaseProperties(resourceMapProvider)
 	// populate columns map
 	if len(t.ColumnList) > 0 {
@@ -88,17 +116,17 @@ func (t *DashboardTable) OnDecoded(_ *hcl.Block, resourceMapProvider ModResource
 	return nil
 }
 
-// AddReference implements HclResource
+// AddReference implements ResourceWithMetadata
 func (t *DashboardTable) AddReference(ref *ResourceReference) {
 	t.References = append(t.References, ref)
 }
 
-// GetReferences implements HclResource
+// GetReferences implements ResourceWithMetadata
 func (t *DashboardTable) GetReferences() []*ResourceReference {
 	return t.References
 }
 
-// GetMod implements HclResource
+// GetMod implements ModTreeItem
 func (t *DashboardTable) GetMod() *Mod {
 	return t.Mod
 }
@@ -108,6 +136,11 @@ func (t *DashboardTable) GetDeclRange() *hcl.Range {
 	return &t.DeclRange
 }
 
+// BlockType implements HclResource
+func (*DashboardTable) BlockType() string {
+	return BlockTypeTable
+}
+
 // AddParent implements ModTreeItem
 func (t *DashboardTable) AddParent(parent ModTreeItem) error {
 	t.parents = append(t.parents, parent)
@@ -124,7 +157,7 @@ func (t *DashboardTable) GetChildren() []ModTreeItem {
 	return nil
 }
 
-// GetTitle implements ModTreeItem, DashboardLeafNode
+// GetTitle implements HclResource, DashboardLeafNode
 func (t *DashboardTable) GetTitle() string {
 	return typehelpers.SafeString(t.Title)
 }
@@ -134,9 +167,9 @@ func (t *DashboardTable) GetDescription() string {
 	return ""
 }
 
-// GetTags implements ModTreeItem
+// GetTags implements HclResource
 func (t *DashboardTable) GetTags() map[string]string {
-	return nil
+	return map[string]string{}
 }
 
 // GetPaths implements ModTreeItem
@@ -198,7 +231,7 @@ func (t *DashboardTable) GetDisplay() string {
 	return typehelpers.SafeString(t.Display)
 }
 
-// GetDocumentation implements DashboardLeafNode
+// GetDocumentation implements DashboardLeafNode, ModTreeItem
 func (*DashboardTable) GetDocumentation() string {
 	return ""
 }
@@ -258,7 +291,7 @@ func (t *DashboardTable) GetPreparedStatementExecuteSQL(runtimeArgs *QueryArgs)
 	return t.getPreparedStatementExecuteSQL(t, runtimeArgs)
 }
 
-func (t *DashboardTable) setBaseProperties(resourceMapProvider ModResourcesProvider) {
+func (t *DashboardTable) setBaseProperties(resourceMapProvider ResourceMapsProvider) {
 	// not all base properties are stored in the evalContext
 	// (e.g. resource metadata and runtime dependencies are not stores)
 	//  so resolve base from the resource map provider (which is the RunContext)
