@@ -47,7 +47,7 @@ type Query struct {
 	parents         []ModTreeItem `json:"-"`
 }
 
-func NewQuery(block *hcl.Block, mod *Mod, shortName string) *Query {
+func NewQuery(block *hcl.Block, mod *Mod, shortName string) HclResource {
 	// queries cannot be anonymous
 	q := &Query{
 		ShortName:       shortName,
@@ -185,21 +185,21 @@ func (q *Query) GetUnqualifiedName() string {
 }
 
 // OnDecoded implements HclResource
-func (q *Query) OnDecoded(*hcl.Block, ModResourcesProvider) hcl.Diagnostics {
+func (q *Query) OnDecoded(*hcl.Block, ResourceMapsProvider) hcl.Diagnostics {
 	return nil
 }
 
-// AddReference implements HclResource
+// AddReference implements ResourceWithMetadata
 func (q *Query) AddReference(ref *ResourceReference) {
 	q.References = append(q.References, ref)
 }
 
-// GetReferences implements HclResource
+// GetReferences implements ResourceWithMetadata
 func (q *Query) GetReferences() []*ResourceReference {
 	return q.References
 }
 
-// GetMod implements HclResource
+// GetMod implements ModTreeItem
 func (q *Query) GetMod() *Mod {
 	return q.Mod
 }
@@ -209,6 +209,11 @@ func (q *Query) GetDeclRange() *hcl.Range {
 	return &q.DeclRange
 }
 
+// BlockType implements HclResource
+func (*Query) BlockType() string {
+	return BlockTypeQuery
+}
+
 // GetParams implements QueryProvider
 func (q *Query) GetParams() []*ParamDef {
 	return q.Params
@@ -276,14 +281,17 @@ func (q *Query) GetDescription() string {
 	return ""
 }
 
-// GetTitle implements ModTreeItem
+// GetTitle implements HclResource
 func (q *Query) GetTitle() string {
 	return typehelpers.SafeString(q.Title)
 }
 
-// GetTags implements ModTreeItem
+// GetTags implements HclResource
 func (q *Query) GetTags() map[string]string {
-	return nil
+	if q.Tags != nil {
+		return q.Tags
+	}
+	return map[string]string{}
 }
 
 // GetPaths implements ModTreeItem
@@ -304,6 +312,11 @@ func (q *Query) SetPaths() {
 	}
 }
 
+// GetDocumentation implement ModTreeItem
+func (q *Query) GetDocumentation() string {
+	return typehelpers.SafeString(q.Documentation)
+}
+
 func (q *Query) Diff(other *Query) *DashboardTreeItemDiffs {
 	res := &DashboardTreeItemDiffs{
 		Item: q,
