@@ -8,9 +8,9 @@ import (
 )
 
 // AddReferences populates the 'References' resource field, used for the introspection tables
-func AddReferences(resource modconfig.HclResource, block *hcl.Block, runCtx *RunContext) hcl.Diagnostics {
-	// NOTE: exclude locals
-	if block.Type == modconfig.BlockTypeLocals {
+func AddReferences(resource modconfig.HclResource, block *hcl.Block, parseCtx *ModParseContext) hcl.Diagnostics {
+	resourceWithMetadata, ok := resource.(modconfig.ResourceWithMetadata)
+	if !ok {
 		return nil
 	}
 
@@ -30,9 +30,9 @@ func AddReferences(resource modconfig.HclResource, block *hcl.Block, runCtx *Run
 						BlockName: blockName,
 						Attribute: attr.Name,
 					}
-					moreDiags := addResourceMetadata(reference, attr.SrcRange, runCtx)
+					moreDiags := addResourceMetadata(reference, attr.SrcRange, parseCtx)
 					diags = append(diags, moreDiags...)
-					resource.AddReference(reference)
+					resourceWithMetadata.AddReference(reference)
 					break
 				}
 			}
