@@ -17,7 +17,7 @@ import {
   LeafNodeDataRow,
 } from "../common";
 import { classNames } from "../../../utils/styles";
-import { DashboardDataMode, useDashboard } from "../../../hooks/useDashboard";
+import { DashboardDataMode, DashboardDataModeLive } from "../../../types";
 import {
   ErrorIcon,
   SortAscendingIcon,
@@ -25,16 +25,17 @@ import {
 } from "../../../constants/icons";
 import { isRelativeUrl } from "../../../utils/url";
 import { memo, useEffect, useMemo, useState } from "react";
+import { registerComponent } from "../index";
 import {
   RowRenderResult,
   renderInterpolatedTemplates,
 } from "../../../utils/template";
 import { ThemeNames } from "../../../hooks/useTheme";
+import { useDashboard } from "../../../hooks/useDashboard";
 import { useSortBy, useTable } from "react-table";
-import { registerComponent } from "../index";
 
-type TableColumnDisplay = "all" | "none";
-type TableColumnWrap = "all" | "none";
+export type TableColumnDisplay = "all" | "none";
+export type TableColumnWrap = "all" | "none";
 
 interface TableColumnInfo {
   Header: string;
@@ -44,6 +45,7 @@ interface TableColumnInfo {
   display?: "all" | "none";
   wrap: TableColumnWrap;
   href_template?: string;
+  sortType?: any;
 }
 
 const getColumns = (
@@ -77,6 +79,9 @@ const getColumns = (
       name: col.name,
       data_type: col.data_type,
       wrap: colWrap,
+      // Boolean data types do not sort under the default alphanumeric sorting logic of react-table
+      // On the next column type that needs specialising we'll move this out into a function / hook
+      sortType: col.data_type === "BOOL" ? "basic" : "alphanumeric",
     };
     if (colHref) {
       colInfo.href_template = colHref;
@@ -138,7 +143,7 @@ const CellValue = ({
       // We only want to render the HREF if it's live, or it's snapshot and absolute
       const isRelative = isRelativeUrl(renderedTemplateForColumn.result);
       setHref(
-        dataMode === "snapshot" && isRelative
+        dataMode !== DashboardDataModeLive && isRelative
           ? null
           : renderedTemplateForColumn.result
       );
@@ -147,7 +152,7 @@ const CellValue = ({
       setHref(null);
       setError(renderedTemplateForColumn.error);
     }
-  }, [column, rowIndex, rowTemplateData]);
+  }, [column, dataMode, rowIndex, rowTemplateData]);
 
   let cellContent;
   const dataType = column.data_type.toLowerCase();
@@ -428,7 +433,7 @@ const TableView = ({
       >
         <thead
           className={classNames(
-            "bg-table-head text-table-head",
+            "text-table-head",
             theme.name === ThemeNames.STEAMPIPE_DARK
               ? "border-b border-table-divide"
               : "border-b border-background"
