@@ -1,8 +1,5 @@
 import { classNames } from "../../../../utils/styles";
-import {
-  ContainerDefinition,
-  DashboardDefinition,
-} from "../../../../hooks/useDashboard";
+import { ContainerDefinition, DashboardDefinition } from "../../../../types";
 import { getResponsivePanelWidthClass } from "../../../../utils/layout";
 
 interface EventMap {
@@ -34,6 +31,7 @@ const LayoutPanel = ({
   const panelWidthClass = getResponsivePanelWidthClass(definition.width);
   return (
     <div
+      id={definition.name}
       className={classNames(
         "grid grid-cols-12 col-span-12 gap-x-4",
         withNarrowVertical ? "gap-y-2" : "gap-y-4 md:gap-y-6",
